Instalación
===========

Existen 2 formas de instalar la biblioteca, así
que veremos cada una por separado.

Opción 1 - Instalación fácil, para cada sistema operativo
---------------------------------------------------------

La forma mas sencilla de instalar pilas es
siguiendo alguno de los tutoriales del sitio
web de pilas:

http://www.pilas-engine.com.ar/documentacion


Opción 2 - Avanzada, desde repositorios
---------------------------------------

Si ya eres un programador avanzado con algo
de experiencia en el lenguaje python, podrías ir directamente
a :ref:`ref_desarrolladores`, en donde encontrarás instrucciones
para acceder directamente al repositorio de pilas.
